Document: cppreference-doc-en-c
Title: C Standard Library reference
Author: Cppreference.com contributors
Abstract: A version of online C and C++ standard library reference manual
 available at en.cppreference.com, suitable for viewing offline.
Section: Programming/C

Format: HTML
Index: /usr/share/cppreference/doc/html/en/c.html
Files: /usr/share/cppreference/doc/html/en/c/*
